filter_merged: 3_Data_processing

View source: R/fct_3_Data_processing.R

filter_mergedR Documentation

3_Data_processing

Description

**Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead.

Usage

filter_merged(
  FBM,
  merged_df,
  merged_header,
  use_rgermline,
  use_repertoire,
  use_productive,
  use_nonproductive,
  my_regions,
  my_var_elements,
  my_vars,
  my_vartypes,
  use_sharedVDJ,
  V_J_to_use,
  groups,
  group_A,
  group_B,
  group_C,
  univlog = FALSE,
  samples_to_keep,
  variables_to_remove,
  pval_type,
  pval_cutoff,
  estimate_cutoff,
  number_selected_vars,
  VJ_deselected,
  VDJ_normalized_per_size,
  R_mut_threshold_min,
  R_mut_threshold_max,
  to_compare_groups,
  VDJ_maximize_clones,
  VDJ_normalized_per_sample,
  my_clone_def,
  seed,
  chains,
  igsubtypes
)

Value

The return value, if any, from executing the function.

Examples


  # Internal function exported for shinymeta :: access during report rendering.
  # Requires a live Shiny reactive context and real AIRR-seq data.
  # Use run_app() as the user-facing entry point.


AbSolution documentation built on April 27, 2026, 9:07 a.m.