View source: R/utils_3_Data_processing.R
| Ab_palette | R Documentation |
#' @description **Internal function.** Not intended for direct use. Exported only for 'shinymeta' report rendering via '::' access. Use [run_app()] instead. Returns a vector of colors according to the input. For V/D/J/VJ/VDJ inputs, the colors are produced in a way that genes and combination of genes from the same family are assigned a similar color.
Ab_palette(
list_values,
vect_genes_comb = NA,
type_values = c("V", "D", "J", "VJ", "VDJ", "cuantitative", "cualitative"),
colorblind = FALSE,
seed = 1234
)
list_values |
For V(D)J combinations, a list of lists of the families of each segment and the genes within them. For V/D/J segments, a list of the families and the genes within them. For cuantitative or cualitative values, a list of values. |
vect_genes_comb |
The vector of the V(D)J combinations present in the dataset if type_values is 'VJ' or 'VDJ'. Otherwise, NA. |
type_values |
One of 'V','D','J','VJ','VDJ', 'cuantitative' or 'cualitative'. 'V','D','J','VJ','VDJ', |
colorblind |
If TRUE, the output is a colorblind-friendly vector of colors from the viridis package. The similarity of the V-D-J colors is lost. |
palette_colors: a (named) vector of colors
# Internal function exported for shinymeta :: access during report rendering.
# Requires a live Shiny reactive context and real AIRR-seq data.
# Use run_app() as the user-facing entry point.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.