| run_app | R Documentation |
Internally, 'run_app()' calls ['shiny::shinyApp()'] to start the
application, using the UI defined in [app_ui()] and the server
logic defined in [app_server()].
run_app(
verbose = FALSE,
onStart = NULL,
options = list(),
enableBookmarking = "server",
uiPattern = "/",
...
)
verbose |
Logical. If |
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |
This function is the entry point that end-users should call after installing the package.
if (interactive()) {
### Launch the full application with default settings:
run_app()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.